/**
 * Demo configuration for testing the OpenCand API with mock data
 * This can be used when the real API is not available
 */

import { type Candidate, type CandidateSearchResult } from '../api';

// Mock candidates for testing
export const MOCK_CANDIDATES: Candidate[] = [
  {
    idCandidato: "6c2be869-339c-47d0-aeb6-77c686e528b5",
    nome: "João Silva",
    cpf: "123.***.789-10",
    dataNascimento: "1990-01-01",
    email: "joao.silva@example.com",
    estadoCivil: "Solteiro",
    sexo: "Masculino",
    ocupacao: "Advogado",
  },
  {
    idCandidato: "7d3cf97a-440d-58e1-bfb7-88d797f639c6",
    nome: "Maria Santos",
    cpf: "987.***.321-45",
    dataNascimento: "1985-05-15",
    email: "maria.santos@example.com",
    estadoCivil: "Casada",
    sexo: "Feminino",
    ocupacao: "Professora",
  },
  {
    idCandidato: "8e4df08b-551e-69f2-cgc8-99e808g750d7",
    nome: "Pedro Oliveira",
    cpf: "456.***.123-78",
    dataNascimento: "1978-12-03",
    email: "pedro.oliveira@example.com",
    estadoCivil: "Divorciado",
    sexo: "Masculino",
    ocupacao: "Empresário",
  },
];

/**
 * Mock search function for testing
 */
export const mockSearchCandidates = (query: string): Promise<CandidateSearchResult> => {
  return new Promise((resolve) => {
    setTimeout(() => {
      const filteredCandidates = MOCK_CANDIDATES.filter(candidate =>
        candidate.nome.toLowerCase().includes(query.toLowerCase()) ||
        candidate.ocupacao.toLowerCase().includes(query.toLowerCase())
      );
      
      resolve({
        candidatos: filteredCandidates
      });
    }, 500); // Simulate network delay
  });
};

export const DEMO_CONFIG = {
  useMockData: import.meta.env.VITE_USE_MOCK_DATA === 'true',
} as const;
